==> winnie-0.1.46.tgz: package/rewidth.js <==
'use strict';

var Ui = require('kenga/utils');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Ui__default = /*#__PURE__*/_interopDefaultLegacy(Ui);

function reWidth(subject, resizer, view) {
  var direction = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
  var onChange = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : null;
  var mouseDownAt = null;
  var mouseDownSplitWidth = null;
  var onMouseUp = null;
  var onMouseMove = null;
  var onViewScroll = null;
  Ui__default['default'].on(resizer.element, Ui__default['default'].Events.DRAGSTART, function (event) {
    if (event.button === 0) {
      event.preventDefault();
      event.stopPropagation();
    }
  });
  Ui__default['default'].on(resizer.element, Ui__default['default'].Events.MOUSEDOWN, function (event) {
    if (event.button === 0) {
      event.stopPropagation();
      mouseDownAt = event.clientX;
      mouseDownSplitWidth = subject.width;

      if (!onMouseUp) {
        onMouseUp = Ui__default['default'].on(document, Ui__default['default'].Events.MOUSEUP, function (event) {
          event.stopPropagation();

          if (onMouseUp) {
            onMouseUp.removeHandler();
            onMouseUp = null;
          }

          if (onMouseMove) {
            onMouseMove.removeHandler();
            onMouseMove = null;
          }

          if (onViewScroll) {
            onViewScroll.removeHandler();
            onViewScroll = null;
          }
        });
      }

      if (!onMouseMove) {
        onMouseMove = Ui__default['default'].on(document, Ui__default['default'].Events.MOUSEMOVE, function (event) {
          event.stopPropagation();
          event.preventDefault();
          var mouseDiff = (event.clientX - mouseDownAt) * direction;
          subject.width = mouseDownSplitWidth + mouseDiff;

          if (onChange) {
            onChange();
          }
        });
      }

      if (!onViewScroll) {
        var oldScrollLeft = view.element.scrollLeft;
        onViewScroll = Ui__default['default'].on(view.element, Ui__default['default'].Events.SCROLL, function (event) {
          view.element.scrollLeft = oldScrollLeft;
        });
      }
    }
  });
}

module.exports = reWidth;

==> winnie-0.1.55.tgz: package/rewidth.js <==
'use strict';

var Ui = require('kenga/utils');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Ui__default = /*#__PURE__*/_interopDefaultLegacy(Ui);

function reWidth(subject, resizer, view) {
  var direction = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
  var onChange = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : null;
  var mouseDownAt = null;
  var mouseDownSplitWidth = null;
  var onMouseUp = null;
  var onMouseMove = null;
  var onViewScroll = null;
  Ui__default["default"].on(resizer.element, Ui__default["default"].Events.DRAGSTART, function (event) {
    if (event.button === 0) {
      event.preventDefault();
      event.stopPropagation();
    }
  });
  Ui__default["default"].on(resizer.element, Ui__default["default"].Events.MOUSEDOWN, function (event) {
    if (event.button === 0) {
      event.stopPropagation();
      mouseDownAt = event.clientX;
      mouseDownSplitWidth = subject.width;

      if (!onMouseUp) {
        onMouseUp = Ui__default["default"].on(document, Ui__default["default"].Events.MOUSEUP, function (event) {
          event.stopPropagation();

          if (onMouseUp) {
            onMouseUp.removeHandler();
            onMouseUp = null;
          }

          if (onMouseMove) {
            onMouseMove.removeHandler();
            onMouseMove = null;
          }

          if (onViewScroll) {
            onViewScroll.removeHandler();
            onViewScroll = null;
          }
        });
      }

      if (!onMouseMove) {
        onMouseMove = Ui__default["default"].on(document, Ui__default["default"].Events.MOUSEMOVE, function (event) {
          event.stopPropagation();
          event.preventDefault();
          var mouseDiff = (event.clientX - mouseDownAt) * direction;
          subject.width = mouseDownSplitWidth + mouseDiff;

          if (onChange) {
            onChange();
          }
        });
      }

      if (!onViewScroll) {
        var oldScrollLeft = view.element.scrollLeft;
        onViewScroll = Ui__default["default"].on(view.element, Ui__default["default"].Events.SCROLL, function (event) {
          view.element.scrollLeft = oldScrollLeft;
        });
      }
    }
  });
}

module.exports = reWidth;
